<?php
/**
 * Implement theme metabox.
 *
 * @package Insights
 */

if (!function_exists('insights_add_theme_meta_box')) :

    /**
     * Add the Meta Box
     *
     * @since 1.0.0
     */
    function insights_add_theme_meta_box()
    {

        $apply_metabox_post_types = array('post', 'page');

        foreach ($apply_metabox_post_types as $key => $type) {
            add_meta_box(
                'insights-theme-settings',
                esc_html__('Single Page/Post Settings', 'insights'),
                'insights_render_theme_settings_metabox',
                $type
            );
        }

    }

endif;

add_action('add_meta_boxes', 'insights_add_theme_meta_box');

add_action( 'admin_enqueue_scripts', 'insights_backend_scripts');
if ( ! function_exists( 'insights_backend_scripts' ) ){
    function insights_backend_scripts( $hook ) {
        wp_enqueue_style( 'wp-color-picker');
        wp_enqueue_script( 'wp-color-picker');
    }
}

if (!function_exists('insights_render_theme_settings_metabox')) :

    /**
     * Render theme settings meta box.
     *
     * @since 1.0.0
     */
    function insights_render_theme_settings_metabox($post, $metabox)
    {

        $post_id = $post->ID;
        $insights_post_meta_value = get_post_meta($post_id);

        // Meta box nonce for verification.
        wp_nonce_field(basename(__FILE__), 'insights_meta_box_nonce');
        // Fetch Options list.
        $insights_meta_checkbox = get_post_meta($post_id, 'insights-meta-checkbox', true);

        $page_layout = get_post_meta($post_id, 'insights-meta-select-layout', true);
        ?>

        <div class="insights-tab-main">

            <div class="insights-metabox-tab">
                <ul>
                    <li>
                        <a id="twp-tab-general" class="twp-tab-active" href="javascript:void(0)"><?php esc_html_e('Layout Settings', 'insights'); ?></a>
                    </li>
                </ul>
            </div>

            <div class="insights-tab-content">
                
                <div id="twp-tab-general-content" class="twp-content-wrap insights-tab-content-active">

                    <div class="insights-meta-panels">

                        <div class="insights-opt-wrap insights-checkbox-wrap">

                            <input id="feature-image-checkbox" name="insights-meta-checkbox" type="checkbox" <?php if ($insights_meta_checkbox) { ?> checked="checked" <?php } ?> />

                            <label for="feature-image-checkbox"><?php esc_html_e('Check To Use Featured Image As Banner Image', 'insights'); ?></label>
                        </div>

                         <div class="insights-opt-wrap insights-opt-wrap-alt">
                            <label><?php esc_html_e('Single Page/Post Layout', 'insights'); ?></label>
                            <select name="insights-meta-select-layout" id="insights-meta-select-layout">
                                <option value="right-sidebar" <?php selected('right-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Content - Primary Sidebar', 'insights') ?>
                                </option>
                                <option value="left-sidebar" <?php selected('left-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Primary Sidebar - Content', 'insights') ?>
                                </option>
                                <option value="no-sidebar" <?php selected('no-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('No Sidebar', 'insights') ?>
                                </option>
                            </select>
                        </div>

                    </div>
                </div>

            </div>
        </div>

        <?php
    }

endif;


if (!function_exists('insights_save_theme_settings_meta')) :

    /**
     * Save theme settings meta box value.
     *
     * @since 1.0.0
     *
     * @param int $post_id Post ID.
     * @param WP_Post $post Post object.
     */
    function insights_save_theme_settings_meta($post_id, $post)
    {

        // Verify nonce.
        if (!isset($_POST['insights_meta_box_nonce']) || !wp_verify_nonce($_POST['insights_meta_box_nonce'], basename(__FILE__))) {
            return;
        }

        // Bail if auto save or revision.
        if (defined('DOING_AUTOSAVE') || is_int(wp_is_post_revision($post)) || is_int(wp_is_post_autosave($post))) {
            return;
        }

        // Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
        if (empty($_POST['post_ID']) || $_POST['post_ID'] != $post_id) {
            return;
        }

        // Check permission.
        if ( is_int( $_POST['post_type'] ) && 'page' === $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) {
                return;
            }
        } else if (!current_user_can('edit_post', $post_id)) {
            return;
        }

        $insights_meta_checkbox = isset( $_POST['insights-meta-checkbox'] ) ? esc_attr( $_POST['insights-meta-checkbox'] ) : '';
        update_post_meta($post_id, 'insights-meta-checkbox', sanitize_text_field($insights_meta_checkbox));

        $insights_meta_select_layout = isset($_POST['insights-meta-select-layout']) ? esc_attr($_POST['insights-meta-select-layout']) : '';
        if (!empty($insights_meta_select_layout)) {
            update_post_meta($post_id, 'insights-meta-select-layout', sanitize_text_field($insights_meta_select_layout));
        }
        
    }

endif;

add_action('save_post', 'insights_save_theme_settings_meta', 10, 3);